@@ -10,7 +10,7 @@ package Net::Plazes;
 use strict;
 use warnings;
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 1;
 __END__
@@ -25,9 +25,9 @@ $Revision$
 
 =head1 SYNOPSIS
 
- my $oUser = Net::Plazes::User->new({id => 123456});
- print $oUser->full_name();
- print map { $_->name(), "\n" } @{$oUser->presences()};
+ my $oUser = Net::Plazes::User->new({id => 266});
+ print $oUser->name();
+ print map { $_->plaze->name() } @{$oUser->activities()}
 
 =head1 DESCRIPTION
 
