@@ -10,18 +10,38 @@ package Net::Plazes::User;
 use strict;
 use warnings;
 use base qw(Net::Plazes::Base);
+use Net::Plazes::Activity;
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 __PACKAGE__->mk_accessors(fields());
 __PACKAGE__->has_many();
 
 sub service {
-  return q[http://plazes.net/users];
+  return q[http://plazes.com/users];
 }
 
 sub fields {
-  return qw(id about created_at full_name name openid_identifier updated_at);
+  return qw(id created_at full_name name updated_at avatar_url);
+}
+
+sub activities {
+  my $self     = shift;
+
+  if(!$self->id()) {
+    return [];
+  }
+
+  if(!$self->{activities}) {
+    my $obj_uri  = sprintf '%s/%d/activities', $self->service(), $self->id();
+    my $root_activity = Net::Plazes::Activity->new({
+						    useragent => $self->useragent(),
+						   });
+    $root_activity->list($obj_uri);
+    $self->{activities} = $root_activity->activities();
+  }
+
+  return $self->{activities};
 }
 
 1;
@@ -29,7 +49,7 @@ __END__
 
 =head1 NAME
 
-Net::Plazes::User - representation of remote resource http://plazes.net/users(.*)
+Net::Plazes::User - representation of remote resource http://plazes.com/users(.*)
 
 =head1 VERSION
 
@@ -47,6 +67,28 @@ $Revision$
 
  my @aFields = $oObj->fields();
 
+=head2 activities - Arrayref of Net::Plazes::Activity objects for this user
+
+ my $arActivities = $oUser->activities();
+
+=head2 accessors
+
+=over
+
+=item id
+
+=item created_at
+
+=item full_name
+
+=item name
+
+=item updated_at
+
+=item avatar_url
+
+=back
+
 =head1 DIAGNOSTICS
 
 =head1 CONFIGURATION AND ENVIRONMENT
